==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/Util__244__241.h <==
// final class org.dellroad.jc.cgen.Util$4$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9eca9254f2abc14b org_dellroad_jc_cgen_Util__244__241
// @dep_class b98ece42af31fd57 org_dellroad_jc_cgen_Util__24OrderTypeSwitch
// @dep_class 12e2cc897947b1d6 soot_TypeSwitch

// header file dependencies
// @dep_header org_dellroad_jc_cgen_Util__24OrderTypeSwitch

#include "org/dellroad/jc/cgen/Util__24OrderTypeSwitch.h"

#ifndef _JC_org_dellroad_jc_cgen_Util__244__241_H_
#define _JC_org_dellroad_jc_cgen_Util__244__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_org_dellroad_jc_cgen_Util__244$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_Util__244__241$sub_refs	_jc_org_dellroad_jc_cgen_Util__244__241$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_Util__244__241$sub_nonrefs	_jc_org_dellroad_jc_cgen_Util__244__241$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_Util__244__241$refs	_jc_org_dellroad_jc_cgen_Util__244__241$refs;
typedef struct _jc_org_dellroad_jc_cgen_Util__244__241$nonrefs	_jc_org_dellroad_jc_cgen_Util__244__241$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_Util__244__241$object	_jc_org_dellroad_jc_cgen_Util__244__241$object;

typedef const struct _jc_org_dellroad_jc_cgen_Util__244__241$vmethods	_jc_org_dellroad_jc_cgen_Util__244__241$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_Util__244__241$vtable	_jc_org_dellroad_jc_cgen_Util__244__241$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_Util__244__241$vtype	_jc_org_dellroad_jc_cgen_Util__244__241$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_Util__244__241$method$_init$4a998c70e812b2f5(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244__241$object *, struct _jc_org_dellroad_jc_cgen_Util__244$object *);

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_Util__244__241$method$order$2916517afc7ab28c(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244__241$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_Util__244__241$method_info$order$2916517afc7ab28c;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_Util__244__241$vmethods {
	void	(*order$2916517afc7ab28c)(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244__241$object *, jint);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_Util__244__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_TypeSwitch$vmethods	soot_TypeSwitch;
	_jc_org_dellroad_jc_cgen_Util__24OrderTypeSwitch$vmethods	org_dellroad_jc_cgen_Util__24OrderTypeSwitch;
	_jc_org_dellroad_jc_cgen_Util__244__241$vmethods	org_dellroad_jc_cgen_Util__244__241;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_Util__244__241$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_Util__244__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_Util__244__241$sub_refs {
	struct _jc_org_dellroad_jc_cgen_Util__244$object	*this;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_Util__244__241$refs {
    _jc_org_dellroad_jc_cgen_Util__244__241$sub_refs	org_dellroad_jc_cgen_Util__244__241;
    _jc_org_dellroad_jc_cgen_Util__24OrderTypeSwitch$sub_refs	org_dellroad_jc_cgen_Util__24OrderTypeSwitch;
    _jc_soot_TypeSwitch$sub_refs	soot_TypeSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_Util__244__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_Util__244__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_TypeSwitch$sub_nonrefs	soot_TypeSwitch;
    _jc_org_dellroad_jc_cgen_Util__24OrderTypeSwitch$sub_nonrefs	org_dellroad_jc_cgen_Util__24OrderTypeSwitch;
    _jc_org_dellroad_jc_cgen_Util__244__241$sub_nonrefs	org_dellroad_jc_cgen_Util__244__241;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_Util__244__241$object {
	_jc_org_dellroad_jc_cgen_Util__244__241$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_Util__244__241$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_Util__244__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_Util__244__241$vtype _jc_org_dellroad_jc_cgen_Util__244__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_Util__244__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_Util__244__241$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_Util__244__241_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/Util__244__241.h <==
// final class org.dellroad.jc.cgen.Util$4$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9eca9254f2abc14b org_dellroad_jc_cgen_Util__244__241
// @dep_class b98ece42af31fd57 org_dellroad_jc_cgen_Util__24OrderTypeSwitch
// @dep_class 12e2cc897947b1d6 soot_TypeSwitch

// header file dependencies
// @dep_header org_dellroad_jc_cgen_Util__24OrderTypeSwitch

#include "org/dellroad/jc/cgen/Util__24OrderTypeSwitch.h"

#ifndef _JC_org_dellroad_jc_cgen_Util__244__241_H_
#define _JC_org_dellroad_jc_cgen_Util__244__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_org_dellroad_jc_cgen_Util__244$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_Util__244__241$sub_refs	_jc_org_dellroad_jc_cgen_Util__244__241$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_Util__244__241$sub_nonrefs	_jc_org_dellroad_jc_cgen_Util__244__241$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_Util__244__241$refs	_jc_org_dellroad_jc_cgen_Util__244__241$refs;
typedef struct _jc_org_dellroad_jc_cgen_Util__244__241$nonrefs	_jc_org_dellroad_jc_cgen_Util__244__241$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_Util__244__241$object	_jc_org_dellroad_jc_cgen_Util__244__241$object;

typedef const struct _jc_org_dellroad_jc_cgen_Util__244__241$vmethods	_jc_org_dellroad_jc_cgen_Util__244__241$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_Util__244__241$vtable	_jc_org_dellroad_jc_cgen_Util__244__241$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_Util__244__241$vtype	_jc_org_dellroad_jc_cgen_Util__244__241$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_Util__244__241$method$_init$4a998c70e812b2f5(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244__241$object *, struct _jc_org_dellroad_jc_cgen_Util__244$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_Util__244__241$method$order$2916517afc7ab28c(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244__241$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_Util__244__241$method_info$order$2916517afc7ab28c;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_Util__244__241$vmethods {
	void	(*order$2916517afc7ab28c)(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244__241$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_Util__244__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_TypeSwitch$vmethods	soot_TypeSwitch;
	_jc_org_dellroad_jc_cgen_Util__24OrderTypeSwitch$vmethods	org_dellroad_jc_cgen_Util__24OrderTypeSwitch;
	_jc_org_dellroad_jc_cgen_Util__244__241$vmethods	org_dellroad_jc_cgen_Util__244__241;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_Util__244__241$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_Util__244__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_Util__244__241$sub_refs {
	struct _jc_org_dellroad_jc_cgen_Util__244$object	*this;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_Util__244__241$refs {
    _jc_org_dellroad_jc_cgen_Util__244__241$sub_refs	org_dellroad_jc_cgen_Util__244__241;
    _jc_org_dellroad_jc_cgen_Util__24OrderTypeSwitch$sub_refs	org_dellroad_jc_cgen_Util__24OrderTypeSwitch;
    _jc_soot_TypeSwitch$sub_refs	soot_TypeSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_Util__244__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_Util__244__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_TypeSwitch$sub_nonrefs	soot_TypeSwitch;
    _jc_org_dellroad_jc_cgen_Util__24OrderTypeSwitch$sub_nonrefs	org_dellroad_jc_cgen_Util__24OrderTypeSwitch;
    _jc_org_dellroad_jc_cgen_Util__244__241$sub_nonrefs	org_dellroad_jc_cgen_Util__244__241;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_Util__244__241$object {
	_jc_org_dellroad_jc_cgen_Util__244__241$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_Util__244__241$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_Util__244__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_Util__244__241$vtype _jc_org_dellroad_jc_cgen_Util__244__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_Util__244__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_Util__244__241$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_Util__244__241_H_ */
